import { DataLayer } from './data-access';
import { Integration } from './integration';
import { Config, EventHandlerReturnType, IntegrationApi, IntegrationApiExcutorParams, IntegrationContext, IntegrationEvent, Routes, ZodeSchemaGenerator } from './types';
import { Blueprint } from './workflows/types';
import { NextRequest, NextResponse } from 'next/server';
import { IntegrationMap } from './generated-types';
import { Prisma } from '@prisma-app/client';
import { z, ZodSchema } from 'zod';
import { VectorLayer } from './vector-access';
import { Logger, RegisteredLogger } from './lib/logger-utils/logger';
export declare class Mastra<C extends Config = Config> {
    globalEvents: Map<string, Record<string, IntegrationEvent<any>>>;
    globalApis: Map<string, Record<string, IntegrationApi<any>>>;
    integrations: Map<string, Integration>;
    dataLayer: DataLayer;
    vectorLayer: VectorLayer;
    agentsConfig: Config['agents'];
    logger: Map<RegisteredLogger, Logger>;
    config: C;
    static init<C extends Config = Config>(config: C): Mastra<C>;
    constructor({ dataLayer, vectorLayer, config, }: {
        dataLayer: DataLayer;
        vectorLayer: VectorLayer;
        config: C;
    });
    attachLogger({ key, logger }: {
        key: RegisteredLogger;
        logger: Logger;
    }): void;
    connectedIntegrations({ context, }: {
        context: {
            connectionId: string;
        };
    }): Promise<Integration<unknown>[]>;
    get routes(): Record<Routes, string>;
    __registerIntgeration(definition: Integration): void;
    registerApi(name: string, api: Omit<IntegrationApi<any>, 'integrationName'>): void;
    registerEvent(name: string, event: Omit<IntegrationEvent<any>, 'integrationName'>): void;
    __registerEvents({ events, integrationName, }: {
        events: Record<string, IntegrationEvent<any>>;
        integrationName?: string;
    }): void;
    __registerApis({ apis, integrationName, }: {
        apis: IntegrationApi[];
        integrationName?: string;
    }): void;
    availableIntegrations(): {
        name: string;
        integration: Integration<unknown>;
    }[];
    getIntegration<T extends keyof IntegrationMap>(name: T): IntegrationMap[T];
    getGlobalEvents(): Map<string, Record<string, IntegrationEvent<any>>>;
    getSystemEvents(): Record<string, IntegrationEvent<any>>;
    getEventsByIntegration(name: string): Record<string, IntegrationEvent<any>> | undefined;
    getGlobalEventHandlers(): EventHandlerReturnType[];
    getApis(): Map<string, Record<string, IntegrationApi<any>>>;
    getSystemApis(): Record<string, IntegrationApi<any>> | undefined;
    getApisByIntegration(name: string, includeHidden?: boolean): Record<string, IntegrationApi<any>> | undefined;
    authenticatableIntegrations(): {
        name: string;
        integration: Integration<unknown>;
    }[];
    authenticator(name: string): import("./authenticator").IntegrationAuth;
    connectIntegrationByCredential({ name, connectionId, credential, }: {
        name: string;
        connectionId: string;
        credential: Omit<Prisma.CredentialUncheckedCreateInput, 'k_id'>;
    }): Promise<void>;
    disconnectIntegration({ name, connectionId, }: {
        name: string;
        connectionId: string;
    }): Promise<void>;
    createSystemConnection(): Promise<{
        name: string;
        connectionId: string;
        id: string;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        createdAt: Date;
        updatedAt: Date | null;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }>;
    callApi({ integrationName, api, payload, }: {
        integrationName?: string;
        api: string;
        payload: IntegrationApiExcutorParams;
    }): Promise<Record<string, any>>;
    subscribeEvent({ id, interval, timeout, }: {
        id: string;
        interval?: number;
        timeout?: number;
    }): Promise<{
        status: string;
        startedAt: string;
        endedAt: string;
    } | null>;
    triggerEvent<KEY extends keyof C['workflows']['systemEvents'], SYSTEM_EVENT_SCHEMA extends C['workflows']['systemEvents'][KEY]['schema']>({ key, data, user, integrationName, }: {
        integrationName?: string;
        key: KEY;
        data: SYSTEM_EVENT_SCHEMA extends ZodSchema ? z.infer<SYSTEM_EVENT_SCHEMA> : SYSTEM_EVENT_SCHEMA extends ZodeSchemaGenerator ? z.infer<Awaited<ReturnType<SYSTEM_EVENT_SCHEMA>>> : never;
        user?: {
            connectionId: string;
            [key: string]: any;
        };
    }): Promise<{
        event: any;
        workflowEvent?: any;
    }>;
    triggerSystemEvent<T = Record<string, any>>({ key, data, user, }: {
        key: string;
        data: T;
        user?: {
            connectionId: string;
            [key: string]: any;
        };
    }): Promise<import("inngest/types").SendEventOutput<{
        id: string;
    }>>;
    createRouter(): {
        makeWebhookUrl: ({ event, name, }: {
            name: string;
            event: string;
        }) => string;
        makeRedirectURI: () => string;
        makeConnectURI: (props: {
            name: string;
            connectionId: string;
            clientRedirectPath: string;
        }) => string;
        registerRoutes: () => (req: NextRequest) => NextResponse<unknown> | Promise<Response>;
    };
    runBlueprint: ({ blueprint, dataCtx, ctx, }: {
        blueprint: Blueprint;
        dataCtx?: any;
        ctx: IntegrationContext;
    }) => Promise<void>;
    getAgent({ connectionId, agentId, }: {
        agentId: string;
        connectionId: string;
    }): Promise<{
        agent: import("openai/resources/beta/assistants").Assistant & {
            _request_id?: string | null;
        };
        initializeThread: (messages?: import("openai/resources/beta/threads/threads").ThreadCreateParams.Message[]) => Promise<import("openai/resources/beta/threads/threads").Thread & {
            _request_id?: string | null;
        }>;
        listMessages: ({ threadId }: {
            threadId: string;
        }) => Promise<import("openai/resources/beta/threads/messages").MessagesPage>;
        getRun: ({ threadId, runId, }: {
            threadId: string;
            runId: string;
        }) => Promise<import("openai/resources/beta/threads/runs/runs").Run & {
            _request_id?: string | null;
        }>;
        handleRunStatus: ({ threadId, run, }: {
            run: import("openai/resources/beta/threads/runs/runs").Run;
            threadId: string;
        }) => Promise<any>;
        handleRequiresAction: ({ threadId, run, }: {
            threadId: string;
            run: import("openai/resources/beta/threads/runs/runs").Run;
        }) => Promise<any>;
        createUserMessage: ({ threadId, content, }: {
            threadId: string;
            content: string;
        }) => Promise<import("openai/resources/beta/threads/messages").Message & {
            _request_id?: string | null;
        }>;
        watchRun: ({ runId, threadId, }: {
            runId?: string;
            threadId: string;
        }) => Promise<any>;
    } | (({ prompt }: {
        prompt: string;
    }) => Promise<import("ai").StreamTextResult<{}>>) | (({ prompt }: {
        prompt: string;
    }) => Promise<import("ai").GenerateTextResult<{}>>) | undefined>;
    get openAIAssistant(): {
        createAssistantAgent: ({ name, instructions, model, tools, response_format, }: {
            name: string;
            tools: import("openai/resources/beta/assistants").AssistantTool[];
            model: string;
            instructions: string;
            response_format?: import("openai/resources/beta/threads/threads").AssistantResponseFormatOption;
        }) => Promise<import("openai/resources/beta/assistants").Assistant & {
            _request_id?: string | null;
        }>;
        getAssistantAgent: ({ id, toolMap, tool_choice, }: {
            id: string;
            toolMap: Record<string, any>;
            tool_choice?: "auto" | "required";
        }) => Promise<{
            agent: import("openai/resources/beta/assistants").Assistant & {
                _request_id?: string | null;
            };
            initializeThread: (messages?: import("openai/resources/beta/threads/threads").ThreadCreateParams.Message[]) => Promise<import("openai/resources/beta/threads/threads").Thread & {
                _request_id?: string | null;
            }>;
            listMessages: ({ threadId }: {
                threadId: string;
            }) => Promise<import("openai/resources/beta/threads/messages").MessagesPage>;
            getRun: ({ threadId, runId, }: {
                threadId: string;
                runId: string;
            }) => Promise<import("openai/resources/beta/threads/runs/runs").Run & {
                _request_id?: string | null;
            }>;
            handleRunStatus: ({ threadId, run, }: {
                run: import("openai/resources/beta/threads/runs/runs").Run;
                threadId: string;
            }) => Promise<any>;
            handleRequiresAction: ({ threadId, run, }: {
                threadId: string;
                run: import("openai/resources/beta/threads/runs/runs").Run;
            }) => Promise<any>;
            createUserMessage: ({ threadId, content, }: {
                threadId: string;
                content: string;
            }) => Promise<import("openai/resources/beta/threads/messages").Message & {
                _request_id?: string | null;
            }>;
            watchRun: ({ runId, threadId, }: {
                runId?: string;
                threadId: string;
            }) => Promise<any>;
        }>;
        updateAssistantAgent: ({ assistantId, name, instructions, model, tools, response_format, }: {
            assistantId: string;
            name: string;
            tools: import("openai/resources/beta/assistants").AssistantTool[];
            model: string;
            instructions: string;
            response_format?: import("openai/resources/beta/threads/threads").AssistantResponseFormatOption;
        }) => Promise<void>;
    };
    __backgroundTasks(): Promise<void>;
}
//# sourceMappingURL=framework.d.ts.map