import { OAuth2Token } from '@badgateway/oauth2-client';
import { Prisma } from '@prisma-app/client';
import { BaseContext } from 'inngest';
import { ZodSchema } from 'zod';
import { Integration } from './integration';
import { LogConfig } from './lib/logger-utils/logger';
export interface WorkflowConfig {
    blueprintDirPath: string;
    systemApis: Omit<IntegrationApi, 'integrationName'>[];
    systemEvents: {
        [key: string]: IntegrationEvent;
    };
}
export interface VectorProvider {
    name: string;
    provider?: unknown;
    apiKey: string;
    dirPath?: string;
}
export interface AgentConfig {
    agentDirPath: string;
    vectorProvider: VectorProvider[];
}
export interface Config<T = any> {
    name: string;
    packageManager?: string;
    systemHostURL: string;
    routeRegistrationPath: string;
    db: {
        provider: string;
        uri: string;
    };
    runner?: {
        provider: string;
        uri: string;
        signingKey?: string;
        eventKey?: string;
    };
    logs?: LogConfig;
    workflows: WorkflowConfig;
    integrations: Integration[];
    env?: {
        provider?: 'local' | 'vercel';
        file?: string;
    };
    agents: AgentConfig;
}
export type IntegrationContext = {
    connectionId: string;
};
export type SchemaFieldOptions = {
    options: {
        [parentValue: string]: {
            value: string;
            label: string;
        }[];
    };
    parentField: string;
} | {
    options: {
        value: string;
        label: string;
    }[];
    parentField?: never;
} | {
    options: undefined;
    parentField?: never;
};
export type frameWorkIcon = {
    icon: string;
    alt: string;
};
export interface IntegrationApiExcutorParams<T extends Record<string, any> = Record<string, any>> {
    data: T;
}
export type ZodeSchemaGenerator = ({ ctx, }: {
    ctx: IntegrationContext;
}) => Promise<ZodSchema>;
export type EventSchema = ZodSchema | ZodeSchemaGenerator;
export type EventHandlerExecutorParams = BaseContext<any>;
export type EventHandlerReturnType = {
    id: string;
    event: string;
    executor: ({ event, step }: EventHandlerExecutorParams) => Promise<any>;
    onFailure?: ({ event, }: {
        event: {
            data: {
                event: {
                    data: Record<string, any>;
                    user: Record<string, string>;
                };
            };
        };
    }) => Promise<any>;
    cancelOn?: {
        event: string;
        if: string;
    }[];
};
/**
 * @param T - the type of the Integration Instance defining the event handler
 */
export type EventHandler<T = unknown> = (params: {
    integrationInstance: T;
    eventKey: string;
    makeWebhookUrl: MakeWebhookURL;
}) => EventHandlerReturnType;
/**
 * @param T - the type of the Integration Instance defining the event handler
 */
export type SystemEventHandler = (params: {
    getIntegration: <T>(integrationName: string) => T;
    getVectorProvider: <P>(vectorProviderName: string) => VectorProvider;
    eventKey: string;
    makeWebhookUrl: MakeWebhookURL;
}) => EventHandlerReturnType;
/**
 * @param T - the type of the Integration Instance
 */
type IntegrationEventHandler<T extends Integration = Integration> = {
    handler?: EventHandler<T> | SystemEventHandler;
};
export type IntegrationEvent<T extends Integration = Integration> = RefinedIntegrationEvent & IntegrationEventHandler<T>;
export type IntegrationApi<IN extends Record<string, any> = Record<string, any>, OUT extends Record<string, any> = Record<string, any>> = {
    integrationName: string;
    schema: ZodSchema<IN> | (({ ctx }: {
        ctx: IntegrationContext;
    }) => Promise<ZodSchema<IN>>);
    outputSchema?: ZodSchema | (({ ctx }: {
        ctx: IntegrationContext;
    }) => Promise<ZodSchema<OUT>>);
    type: string;
    label: string;
    getSchemaOptions?: ({ ctx, }: {
        ctx: IntegrationContext;
    }) => Promise<Record<string, SchemaFieldOptions>>;
    icon?: frameWorkIcon;
    description: string;
    documentation?: string;
    category?: string;
    executor: (params: IntegrationApiExcutorParams<IN>) => Promise<OUT>;
    isHidden?: boolean;
    source?: string;
};
export declare enum IntegrationErrors {
    BROKEN_CONNECTION = "BROKEN_CONNECTION",
    MISSING_SCOPES = "MISSING_SCOPES"
}
export interface IntegrationApiExcutorParams<T> {
    data: T;
    ctx: IntegrationContext;
}
export type RefinedIntegrationApi<T = unknown> = Omit<IntegrationApi, 'getSchemaOptions'> & {
    schemaOptions: Record<string, SchemaFieldOptions>;
    zodSchema: ZodSchema<T>;
    zodOutputSchema: ZodSchema<T>;
};
export type RefinedIntegrationEvent<T = unknown> = {
    schema: EventSchema;
    key?: string;
    integrationName?: string;
    label?: string;
    description?: string;
    getSchemaOptions?: ({ ctx, }: {
        ctx: IntegrationContext;
    }) => Promise<Record<string, SchemaFieldOptions>>;
    zodSchema?: ZodSchema<T>;
    entityType?: string;
    fields?: Prisma.PropertyCreateInput[];
};
export declare enum IntegrationCredentialType {
    OAUTH = "OAUTH",
    API_KEY = "API_KEY",
    SYSTEM = "SYSTEM"
}
export declare const IntegrationFieldTypeEnum: {
    readonly SINGLE_LINE_TEXT: "SINGLE_LINE_TEXT";
    readonly LONG_TEXT: "LONG_TEXT";
    readonly RICH_TEXT: "RICH_TEXT";
    readonly SINGLE_SELECT: "SINGLE_SELECT";
    readonly MULTI_SELECT: "MULTI_SELECT";
    readonly CREATABLE_SELECT: "CREATABLE_SELECT";
    readonly CHECKBOX: "CHECKBOX";
    readonly DATE: "DATE";
    readonly USER: "USER";
    readonly BADGE_LIST: "BADGE_LIST";
    readonly CURRENCY: "CURRENCY";
    readonly URL: "URL";
    readonly PHONE: "PHONE";
    readonly CONTACT: "CONTACT";
    readonly COMPANY: "COMPANY";
    readonly COMPOSITE: "COMPOSITE";
    readonly PERSON: "PERSON";
    readonly ENRICHMENT: "ENRICHMENT";
};
export type IntegrationFieldType = keyof typeof IntegrationFieldTypeEnum;
export type OAuthToken = OAuth2Token & {
    [key: string]: any;
};
export type APIKey = {
    apiKey: string;
} & {
    [key: string]: any;
};
export type CredentialValue = OAuthToken | APIKey;
export type AuthToken = Omit<OAuthToken, 'refreshToken'> | APIKey;
export type MakeWebhookURL = ({ event, name, }: {
    name: string;
    event: string;
}) => string;
export type QueryResult<T> = {
    data: T;
};
export type Routes = 'connect' | 'callback' | 'inngest' | 'webhook' | 'cron';
export interface OpenAPI {
    openapi: string;
    info: OpenAPI_Info;
    servers?: OpenAPI_Server[];
    paths: OpenAPI_Paths;
    components?: OpenAPI_Components;
    security?: OpenAPI_SecurityRequirement[];
    tags?: OpenAPI_Tag[];
    externalDocs?: OpenAPI_ExternalDocumentation;
}
export interface OpenAPI_Info {
    title: string;
    version: string;
    description?: string;
    termsOfService?: string;
    contact?: OpenAPI_Contact;
    license?: OpenAPI_License;
}
export interface OpenAPI_Contact {
    name?: string;
    url?: string;
    email?: string;
}
export interface OpenAPI_License {
    name: string;
    url?: string;
}
export interface OpenAPI_Server {
    url: string;
    description?: string;
}
export interface OpenAPI_Paths {
    [path: string]: OpenAPI_PathItem;
}
export interface OpenAPI_PathItem {
    summary?: string;
    description?: string;
    get?: OpenAPI_Operation;
    put?: OpenAPI_Operation;
    post?: OpenAPI_Operation;
    delete?: OpenAPI_Operation;
    options?: OpenAPI_Operation;
    head?: OpenAPI_Operation;
    patch?: OpenAPI_Operation;
    trace?: OpenAPI_Operation;
    servers?: OpenAPI_Server[];
    parameters?: OpenAPI_Parameter[];
}
export interface OpenAPI_Operation {
    summary?: string;
    description?: string;
    operationId?: string;
    parameters?: OpenAPI_Parameter[];
    requestBody?: OpenAPI_RequestBody;
    responses: OpenAPI_Responses;
    deprecated?: boolean;
    security?: OpenAPI_SecurityRequirement[];
    tags?: string[];
    servers?: OpenAPI_Server[];
}
export interface OpenAPI_Parameter {
    name: string;
    in: 'query' | 'header' | 'path' | 'cookie';
    description?: string;
    required?: boolean;
    schema: OpenAPI_Schema;
    $ref?: string;
    example?: string | string[];
    enum?: string[];
}
export interface OpenAPI_RequestBody {
    description?: string;
    content: {
        [mediaType: string]: OpenAPI_MediaType;
    };
    required?: boolean;
}
export interface OpenAPI_MediaType {
    schema: OpenAPI_Schema;
}
export interface OpenAPI_Responses {
    [statusCode: string]: OpenAPI_Response;
}
export interface OpenAPI_Response {
    description: string;
    content?: {
        [mediaType: string]: OpenAPI_MediaType;
    };
    headers?: {
        [headerName: string]: OpenAPI_Header;
    };
    links?: {
        [linkName: string]: OpenAPI_Link;
    };
}
export interface OpenAPI_Header {
    description?: string;
    schema: OpenAPI_Schema;
}
export interface OpenAPI_Link {
    operationRef?: string;
    operationId?: string;
    parameters?: {
        [parameterName: string]: any;
    };
    requestBody?: any;
    description?: string;
}
export interface OpenAPI_Schema {
    type?: string;
    format?: string;
    properties?: {
        [propertyName: string]: OpenAPI_Schema;
    };
    required?: string[];
    items?: OpenAPI_Schema;
    enum?: any[];
    example?: any;
    $ref?: string;
    allOf?: OpenAPI_Schema[];
}
export interface OpenAPI_Components {
    schemas?: {
        [schemaName: string]: OpenAPI_Schema;
    };
    responses?: {
        [responseName: string]: OpenAPI_Response;
    };
    parameters?: {
        [parameterName: string]: OpenAPI_Parameter;
    };
    requestBodies?: {
        [requestBodyName: string]: OpenAPI_RequestBody;
    };
    headers?: {
        [headerName: string]: OpenAPI_Header;
    };
    securitySchemes?: {
        [securitySchemeName: string]: OpenAPI_SecurityScheme;
    };
    links?: {
        [linkName: string]: OpenAPI_Link;
    };
    callbacks?: {
        [callbackName: string]: OpenAPI_PathItem;
    };
}
export interface OpenAPI_SecurityScheme {
    type: 'apiKey' | 'http' | 'oauth2' | 'openIdConnect';
    in?: 'query' | 'header' | 'cookie';
    name?: string;
    scheme?: string;
    bearerFormat?: string;
    flows?: OpenAPI_OAuthFlows;
    openIdConnectUrl?: string;
}
export interface OpenAPI_OAuthFlows {
    implicit?: OpenAPI_OAuthFlow;
    password?: OpenAPI_OAuthFlow;
    clientCredentials?: OpenAPI_OAuthFlow;
    authorizationCode?: OpenAPI_OAuthFlow;
}
export interface OpenAPI_OAuthFlow {
    authorizationUrl?: string;
    tokenUrl?: string;
    refreshUrl?: string;
    scopes: {
        [scope: string]: string;
    };
}
export interface OpenAPI_SecurityRequirement {
    [securitySchemeName: string]: string[];
}
export interface OpenAPI_Tag {
    name: string;
    description?: string;
    externalDocs?: OpenAPI_ExternalDocumentation;
}
export interface OpenAPI_ExternalDocumentation {
    description?: string;
    url: string;
}
export interface OpenAPI_Callback {
    [callbackName: string]: OpenAPI_PathItem;
}
export {};
//# sourceMappingURL=types.d.ts.map